# Fulgora <img src="https://github.com/user-attachments/assets/b3ab0b3b-f462-4830-b77d-681a78b6858c" alt="logo" width="100"/>  

**Fulgora** is a Python wrapper for Gaussian that allows users to pass in a Crystallographic Information File (CIF) and compute the total energy using Gaussian's quantum chemistry calculations.

## Features

- Accepts input in the form of CIF files
- Interfaces with Gaussian to compute the total energy of a given molecular structure
- Simplifies the process of setting up Gaussian calculations for crystallographic data
- Easy-to-use command-line interface

## Prerequisites

- **Gaussian 16**: Ensure that Gaussian is installed and accessible on your system.
- **Python 3.x**: Fulgora requires Python 3.10 or higher.

## Installation 

Fulgora can be used locally by installing the project with pip

    pip install .
